@@ -3,16 +3,15 @@
 # SPDX-License-Identifier: Apache-2.0
 
 echo $1
-if [ "$(echo "intel123" | sudo docker ps -q -f name=^cadvisor$)" ]; then
-    echo "Stoping and Deleting Docker-Telemetry service"
+if [ "$(echo "intel123" | sudo docker ps -q -f name=^docker_cadvisor$)" ]; then
+    echo -e "\e[1;32m\nStoping and Deleting Docker-Telemetry service\e[0m"
     export HOST_IP=$(hostname -I | cut -d' ' -f1)
     if [ $1=="all-services" ]; then 
         ver=$(python3 --version | grep Python | awk '{print $2}' | xargs printf '%0.1f\n')
-        sudo -E docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/docker-telemetry/docker-compose-app-service.yaml stop influxdb grafana cadvisor prometheus
-	sudo docker rm -f $(sudo docker ps -aq)
+        docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/docker-telemetry/docker-compose-app-service.yaml stop grafana cadvisor prometheus
     else
 	ver=$(python3 --version | grep Python | awk '{print $2}' | xargs printf '%0.1f\n')
-        sudo -E docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/docker-telemetry/docker-compose-app-service.yaml stop $1
+        docker-compose -f /usr/local/lib/python$ver/dist-packages/src/scripts/app-services/docker-telemetry/docker-compose-app-service.yaml stop $1
     fi
 else
     echo "Docker-Telemetry is not running"
