@@ -23,7 +23,7 @@ if [[ $(which pip) && $(pip --version) ]]; then
 sudo docker pull openvino/workbench:2021.4.2
 echo -e "\e[1;32mWorkbench image is pulled successfully\e[0m"
 echo -e "\e[1;35mTo view the images: docker images\e[0m"
-echo -e "\e[1;31m\nFor further queries please follow below URL\e[0m"
+echo -e "\e[1;31m\nRefer below URL to get started:\e[0m"
 echo -e "\e[1;32mhttps://docs.openvino.ai/latest/workbench_docs_Workbench_DG_Install.html\e[0m"
 
 
