@@ -13,4 +13,5 @@ fi
 
 omz_downloader --name efficientdet-d0-tf
 echo -e "\e[1;32mmodel is downloaded under the public folder\e[0m"
-
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+echo -e "\e[1;32m\nhttps://github.com/openvinotoolkit/open_model_zoo/tree/master/models/public/efficientdet-d0-tf[0m"
