@@ -14,3 +14,6 @@ fi
 omz_downloader --name resnet-50-pytorch
 echo -e "\e[1;32mmodel is downloaded under the public folder\e[0m"
 
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+echo -e "\e[1;32m\nhttps://github.com/openvinotoolkit/open_model_zoo/tree/master/models/public/resnet-50-pytorch\e[0m"
+
