@@ -23,6 +23,9 @@ if [[ $(sudo pip3 show openvino-tensorflow ) ]]; then
      else
          echo -e "\e[1;32mInstalling openvino-tensorflow ....\e[0m"
          sudo pip3 install openvino-tensorflow==2.0.0
+	 echo -e "\e[1;32mInstalled openvino-tensorflow successfully\e[0m"
+	 echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+	 echo -e "\e[1;32m\nhttps://openvinotoolkit.github.io/openvino_tensorflow/\e[0m"
 fi
 
 
