@@ -4,10 +4,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 
-echo -e "\e[1;32mWork in Progress\e[0m"
-
-
-echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+echo -e "\e[1;31mdownaload the Dataset from below URL:\e[0m"
 
 
 echo -e "\e[1;32mhttp://shuoyang1213.me/WIDERFACE/\e[0m"
