@@ -39,7 +39,7 @@ echo "Installing MONAI"
 
 pip install monai
 
-echo -e "\e[1;34mMONAI folder is downloaded in \home\intel\<username>\e[0m\n"
+echo -e "\e[1;34mMONAI folder is downloaded successfully in Workload folder\e[0m\n"
 
 #Check RI is installed sucessfully
 
